@@ -15,37 +15,39 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with GNU Libidn; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  *
  */
 
 #ifndef PR29_H
-#define PR29_H
+# define PR29_H
 
-#ifdef __cplusplus
+# ifdef __cplusplus
 extern "C"
 {
-#endif
+# endif
 
   /* Get size_t. */
-#include <stdlib.h>
+# include <stdlib.h>
 
   /* Get uint32_t. */
-#include <idn-int.h>
+# include <idn-int.h>
 
   /* Error codes. */
   typedef enum
-    {
-      PR29_SUCCESS = 0,
-      PR29_PROBLEM = 1,		  /* String is a problem sequence. */
-      PR29_STRINGPREP_ERROR = 2   /* Charset conversion failed (p29_8*). */
-    } Pr29_rc;
+  {
+    PR29_SUCCESS = 0,
+    PR29_PROBLEM = 1,		/* String is a problem sequence. */
+    PR29_STRINGPREP_ERROR = 2	/* Charset conversion failed (p29_8*). */
+  } Pr29_rc;
 
-  extern int pr29_4 (const uint32_t *in, size_t len);
-  extern int pr29_4z (const uint32_t *in);
+  extern const char *pr29_strerror (Pr29_rc rc);
+
+  extern int pr29_4 (const uint32_t * in, size_t len);
+  extern int pr29_4z (const uint32_t * in);
   extern int pr29_8z (const char *in);
 
-#ifdef __cplusplus
+# ifdef __cplusplus
 }
-#endif
+# endif
 #endif				/* PR29_H */
